import setuptools

setuptools.setup(
	name='systemJSON',
	version='0.1',
	author='DanXvo',
	author_email='coldreality@mail.ru',
	description='is lib for json',
	packages=['systemJSON'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)